/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.knowledgebase.service.permission;

import com.liferay.knowledgebase.model.KBTemplate;
import com.liferay.knowledgebase.service.KBTemplateLocalServiceUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.security.auth.PrincipalException;
import com.liferay.portal.security.permission.PermissionChecker;

/**
 * @author Peter Shin
 * @author Brian Wing Shun Chan
 */
public class KBTemplatePermission {

	public static void check(
			PermissionChecker permissionChecker, long kbTemplateId,
			String actionId)
		throws PortalException, SystemException {

		if (!contains(permissionChecker, kbTemplateId, actionId)) {
			throw new PrincipalException();
		}
	}

	public static void check(
			PermissionChecker permissionChecker, KBTemplate kbTemplate,
			String actionId)
		throws PortalException {

		if (!contains(permissionChecker, kbTemplate, actionId)) {
			throw new PrincipalException();
		}
	}

	public static boolean contains(
			PermissionChecker permissionChecker, long kbTemplateId,
			String actionId)
		throws PortalException, SystemException {

		KBTemplate kbTemplate = KBTemplateLocalServiceUtil.getKBTemplate(
			kbTemplateId);

		return contains(permissionChecker, kbTemplate, actionId);
	}

	public static boolean contains(
		PermissionChecker permissionChecker, KBTemplate kbTemplate,
		String actionId) {

		if (permissionChecker.hasOwnerPermission(
				kbTemplate.getCompanyId(), KBTemplate.class.getName(),
				kbTemplate.getKbTemplateId(), kbTemplate.getUserId(),
				actionId)) {

			return true;
		}

		return permissionChecker.hasPermission(
			kbTemplate.getGroupId(), KBTemplate.class.getName(),
			kbTemplate.getKbTemplateId(), actionId);
	}

}